@@ -21,19 +21,10 @@ glmQLFit.DGEList <- function(y, design=NULL, dispersion=NULL, abundance.trend=TR
 
 	if(is.null(y$AveLogCPM)) y$AveLogCPM <- aveLogCPM(y)
 
-	if(is.null(dispersion)) {
-		if(legacy) {
-			dispersion <- y$trended.dispersion
-			if(is.null(dispersion)) dispersion <- y$common.dispersion
-			if(is.null(dispersion)) stop("No dispersion values found in DGEList object.")
-		} else {
-			if(!is.null(y$trended.dispersion)) {
-				# Set dispersion to mean of upper 10% tail of trended dispersions
-				ntop <- ceiling(0.1 * nrow(y))
-				i <- order(y$AveLogCPM,decreasing=TRUE)[1:ntop]
-				dispersion <- mean(y$trended.dispersion[i])
-			}
-		}
+	if(is.null(dispersion) && legacy) {
+		dispersion <- y$trended.dispersion
+		if(is.null(dispersion)) dispersion <- y$common.dispersion
+		if(is.null(dispersion)) stop("No dispersion values found in DGEList object.")
 	}
 
 	offset <- getOffset(y)
